==> crow-2.15.0.tar.bz2: crow-2.15.0/service/container.h <==
/*
 *  Crow, a GUI designer for GTK+
 *  Copyright (c) 2005-2009 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person
 *  obtaining a copy of this software and associated documentation
 *  files (the "Software"), to deal in the Software without
 *  restriction, including without limitation the rights to use, copy,
 *  modify, merge, publish, distribute, sublicense, and/or sell copies
 *  of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind,
 *  express or implied, including but not limited to the warranties of
 *  merchantability, fitness for a particular purpose and
 *  noninfringement. In no event shall the authors or copyright
 *  holders be liable for any claim, damages or other liability,
 *  whether in an action of contract, tort or otherwise, arising from,
 *  out of or in connection with the software or the use or other
 *  dealings in the software.
 */

#ifndef CROWSVC_CONTAINER_H
#define CROWSVC_CONTAINER_H

#include "util.h"

typedef struct CrowContainer CrowContainer;
typedef struct CrowContainerClass CrowContainerClass;

struct CrowContainer {
  GObject parent;
	int counter;
	GHashTable * designers;
	char ** defIconPath;
};

struct CrowContainerClass {
  GObjectClass parent;
	GObjectClass * parent_class;
};

#define CROW_TYPE_CONTAINER (crow_container_get_type())
#define CROW_CONTAINER(object) (G_TYPE_CHECK_INSTANCE_CAST((object), CROW_TYPE_CONTAINER, CrowContainer))
#define CROW_CONTAINER_CLASS(meta) (G_TYPE_CHECK_CLASS_CAST((meta), CROW_TYPE_CONTAINER, CrowContainerClass))
#define CROW_IS_CONTAINER(object) (G_TYPE_CHECK_INSTANCE_TYPE((object), CROW_TYPE_CONTAINER))
#define CROW_IS_CONTAINER_CLASS(meta) (G_TYPE_CHECK_CLASS_TYPE((meta), CROW_TYPE_CONTAINER))
#define CROW_CONTAINER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), CROW_TYPE_CONTAINER, CrowContainerClass))

GType crow_container_get_type(void);
void crow_container_class_init(CrowContainerClass * meta);
void crow_container_init(CrowContainer * obj);
void crow_container_finalize(GObject * object);

CrowContainer ** ContainerPtr(void);
CrowContainer * ContainerGet(void);
void ContainerEnter(void);
void ContainerLeave(void);
void ContainerInit(CrowContainer * obj);
void ContainerDone(CrowContainer * obj);
CrowDesigner * CreateDesigner(GdkNativeWindow handle);
void RemoveDesigner(gpointer value);
CrowDesigner * FindDesigner(CrowContainer * obj, int id);
GHashTable * CloneSettings(GHashTable * settings);
void CloneSetting(gpointer key, gpointer value, gpointer result);
char ** VStrMerge(char ** vstr1, char ** vstr2);
gboolean VStrEqual(char ** vstr1, char ** vstr2);

void OnActionsUpdated(CrowDesigner * obj, CrowActions changed, CrowContainer * container);
void OnStatusUpdated(CrowDesigner * obj, const char * status, CrowContainer * container);
void OnInfoUpdated(CrowDesigner * obj, const char * info, CrowContainer * container);
void OnShowUrl(CrowDesigner * obj, const char * url, CrowContainer * container);
void OnModalEnter(CrowDesigner * obj, CrowContainer * container);
void OnModalLeave(CrowDesigner * obj, CrowContainer * container);

gboolean crow_container_get_version(CrowContainer * obj, int * version, GError ** error);
gboolean crow_container_shutdown(CrowContainer * obj, GError ** error);
gboolean crow_container_create(CrowContainer * obj, gint64 handle, int * id, GError ** error);
gboolean crow_container_remove(CrowContainer * obj, int id, GError ** error);
gboolean crow_container_apply_settings(CrowContainer * obj, int id, GHashTable * settings, GError ** error);
gboolean crow_container_store_settings(CrowContainer * obj, int id, GHashTable * original, GHashTable ** settings, GError ** error);
gboolean crow_container_clear(CrowContainer * obj, int id, GError ** error);
gboolean crow_container_load(CrowContainer * obj, int id, const char * data, GError ** error);
gboolean crow_container_save(CrowContainer * obj, int id, char ** data, GError ** error);
gboolean crow_container_save_header(CrowContainer * obj, int id, char ** data, GError ** error);
gboolean crow_container_saved(CrowContainer * obj, int id, GError ** error);
gboolean crow_container_get_enabled_actions(CrowContainer * obj, int id, gint64 * actions, GError ** error);
gboolean crow_container_run_action(CrowContainer * obj, int id, gint64 action, GError ** error);

#endif

==> crow-2.17.1.tar.bz2: crow-2.17.1/service/container.h <==
/*
 *  Crow, a GUI designer for GTK+
 *  Copyright (c) 2005-2010 Maxim Udushlivy
 *
 *  Permission is hereby granted, free of charge, to any person
 *  obtaining a copy of this software and associated documentation
 *  files (the "Software"), to deal in the Software without
 *  restriction, including without limitation the rights to use, copy,
 *  modify, merge, publish, distribute, sublicense, and/or sell copies
 *  of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be
 *  included in all copies or substantial portions of the Software.
 *
 *  The software is provided "as is", without warranty of any kind,
 *  express or implied, including but not limited to the warranties of
 *  merchantability, fitness for a particular purpose and
 *  noninfringement. In no event shall the authors or copyright
 *  holders be liable for any claim, damages or other liability,
 *  whether in an action of contract, tort or otherwise, arising from,
 *  out of or in connection with the software or the use or other
 *  dealings in the software.
 */

#ifndef CROWSVC_CONTAINER_H
#define CROWSVC_CONTAINER_H

#include "util.h"

#define CROW_TYPE_CONTAINER (crow_container_get_type())
#define CROW_CONTAINER(object) (G_TYPE_CHECK_INSTANCE_CAST((object), CROW_TYPE_CONTAINER, CrowContainer))
#define CROW_CONTAINER_CLASS(meta) (G_TYPE_CHECK_CLASS_CAST((meta), CROW_TYPE_CONTAINER, CrowContainerClass))
#define CROW_IS_CONTAINER(object) (G_TYPE_CHECK_INSTANCE_TYPE((object), CROW_TYPE_CONTAINER))
#define CROW_IS_CONTAINER_CLASS(meta) (G_TYPE_CHECK_CLASS_TYPE((meta), CROW_TYPE_CONTAINER))
#define CROW_CONTAINER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), CROW_TYPE_CONTAINER, CrowContainerClass))

namespace CrowSvc {

class Container;
typedef struct CrowContainer CrowContainer;
typedef struct CrowContainerClass CrowContainerClass;

struct CrowContainer {
	GObject parent;
	Container * container;
};

struct CrowContainerClass {
	GObjectClass parent;
	GObjectClass * parent_class;
};

GType crow_container_get_type();
void crow_container_class_init(CrowContainerClass * meta);
void crow_container_init(CrowContainer * obj);
void crow_container_finalize(GObject * object);

class Container {

public:
	Container();
	~Container();
	PDesigner lookup(int id);
	void remove(int id);
	int insert(PDesigner designer);

	const StringSet * defIconPath() { return &iconPath; }

protected:
	void freePlug(PDesigner designer);

private:
	typedef std::map<int, PDesigner> Table;

	int counter;
	Table designers;
	StringSet iconPath;

};

CrowContainer *& ContainerPtr();
CrowContainer * ContainerGet();
void ContainerEnter();
void ContainerLeave();
void ContainerInit(CrowContainer * obj);
void ContainerDone(CrowContainer * obj);
PDesigner MakeDesigner(GdkNativeWindow handle);
PDesigner FindDesigner(CrowContainer * obj, int id);

class ContainerBlock {
public:
	ContainerBlock() { ContainerEnter(); }
	~ContainerBlock() { ContainerLeave(); }
};

void OnActionsUpdated(CrowActions changed, int id, CrowContainer * container);
void OnStatusUpdated(ustring_cr status, int id, CrowContainer * container);
void OnInfoUpdated(ustring_cr info, int id, CrowContainer * container);
void OnShowUrl(ustring_cr url, int id, CrowContainer * container);
void OnModalEnter(int id, CrowContainer * container);
void OnModalLeave(int id, CrowContainer * container);

gboolean crow_container_get_version(CrowContainer * obj, int * version, GError ** error);
gboolean crow_container_shutdown(CrowContainer * obj, GError ** error);
gboolean crow_container_create(CrowContainer * obj, gint64 handle, int * id, GError ** error);
gboolean crow_container_remove(CrowContainer * obj, int id, GError ** error);
gboolean crow_container_apply_settings(CrowContainer * obj, int id, GHashTable * settings, GError ** error);
gboolean crow_container_store_settings(CrowContainer * obj, int id, GHashTable * original, GHashTable ** settings, GError ** error);
gboolean crow_container_clear(CrowContainer * obj, int id, GError ** error);
gboolean crow_container_load(CrowContainer * obj, int id, const char * data, GError ** error);
gboolean crow_container_save(CrowContainer * obj, int id, char ** data, GError ** error);
gboolean crow_container_save_header(CrowContainer * obj, int id, char ** data, GError ** error);
gboolean crow_container_saved(CrowContainer * obj, int id, GError ** error);
gboolean crow_container_get_enabled_actions(CrowContainer * obj, int id, gint64 * actions, GError ** error);
gboolean crow_container_run_action(CrowContainer * obj, int id, gint64 action, GError ** error);

}

#endif
